@@ -97,6 +97,7 @@ extern	char *home;		/* pointer to home directory for glob */
 extern	FILE *ftpd_popen(), *fopen(), *freopen();
 extern	int  ftpd_pclose(), fclose();
 extern	char *getline();
+extern	char *copy();
 extern	char cbuf[];
 static struct {
 	char	name[512];	/* last login name tried */
@@ -536,7 +537,7 @@ pass(passwd)
 	}
 	login_attempts = 0;		/* this time successful */
 	last.failures = 0;
-	syslog(LOG_NOTICE, "login from %s as %s", remotehost, pw->pw_name);
+	syslog(LOG_INFO, "login from %s as %s", remotehost, pw->pw_name);
 	(void) setegid((gid_t)pw->pw_gid);
 	(void) initgroups(pw->pw_name, pw->pw_gid);
 
@@ -604,7 +605,7 @@ pass(passwd)
 #ifdef STATS
 		if (ident != NULL)
 			free(ident);
-		ident = (char *)copy(passwd);
+		ident = copy(passwd);
 #endif
 #ifdef SETPROCTITLE
 		sprintf(proctitle, "%s: anonymous/%.*s", remotehost,
@@ -1563,9 +1564,16 @@ logxfer(name, size, start)
 	char path[MAXPATHLEN + 1];
 	long now;
 
-	if (statfd >= 0 && getwd(path) != NULL) {
+	if (statfd >= 0) {
+		if (name[0] == '/') {
+			path[0] = 0;
+		} else if (getwd(path) != 0) {
+			strcat(path, "/");
+		} else {
+			return;
+		}
 		time(&now);
-		sprintf(buf, "%.20s!%s!%s!%s/%s!%ld!%ld\n",
+		sprintf(buf, "%.20s!%s!%s!%s%s!%ld!%ld\n",
 			ctime(&now)+4, ident, remotehost,
 			path, name, size, now - start + (now == start));
 		write(statfd, buf, strlen(buf));
