@@ -58,6 +58,12 @@ static char sccsid[] = "@(#)login.c	5.32.1.1 (Berkeley) 1/28/89";
 #define UT_NAMESIZE	sizeof(((struct UTMP_STRUCT *)0)->ut_name)
 #endif /* UT_NAMESIZE */
 
+#ifdef DECOSF1_ENHANCED
+#include <sys/types.h>
+#include <sys/security.h>
+#include <prot.h>
+#endif
+
 #include <signal.h>
 #ifdef USE_OUR_LASTLOG_H
 #include "lastlog.h"
@@ -212,6 +218,10 @@ main(argc, argv)
 	int mask;
 	int maxtrys;
 #endif /* SYSV_LOGINDEFS */
+#ifdef DECOSF1_ENHANCED
+	struct pr_passwd *pr;
+	(void) set_auth_parameters(argc, argv);
+#endif
 
 #ifdef RLIMIT_CORE
 	/* Disable core dumps with cleartext or shadow passwords. */
@@ -432,7 +442,18 @@ main(argc, argv)
 		}
 		(void)strcpy(tbuf, username);
 		if (pwd = getpwnam(username))
+#ifdef DECOSF1_ENHANCED
+		{
+			if (pr = getprpwnam(username)) {
+				pwd->pw_passwd = strdup(pr->ufld.fd_encrypt);
+				salt = pwd->pw_passwd;
+			} else {
+				salt = "xx";
+			}
+		}
+#else
 			salt = pwd->pw_passwd;
+#endif
 		else
 			salt = "xx";
 
@@ -594,6 +615,13 @@ main(argc, argv)
 
 	initgroups(username, pwd->pw_gid);
 
+#ifdef DECOSF1_ENHANCED
+	if (setluid(pwd->pw_uid)) {
+		printf("login: setluid(%d) error\n", pwd->pw_uid);
+		sleepexit(0);
+	}
+#endif
+
 	if (setuid(pwd->pw_uid)) {
 		printf("login: bad uid: %d\n", pwd->pw_uid);
 		sleepexit(0);
