@@ -6,7 +6,7 @@
   * 
   * The user argument is a struct passwd pointer. All other arguments are
   * null-terminated strings. Specify a null pointer where information is not
-  * available (user is required).
+  * available.
   * 
   * When no address information is given this code performs the host (internet)
   * address lookup itself. It rejects addresses that appear to belong to
@@ -57,7 +57,7 @@ static char *need_internet_addr();
   */
 #define match_host_name(l)	match_token((l)->host_name)
 #define match_port(l)		match_token((l)->port)
-#define match_user(l)		match_token((l)->user->pw_name)
+#define match_user(l)		((l)->user && match_token((l)->user->pw_name))
 static int match_internet_addr();
 static int match_group();
 static int match_token();
@@ -291,6 +291,8 @@ struct login_info *login_info;
     char   *tok;
     char  **memp;
 
+    if (login_info->user == 0)
+	return (0);
     if ((tok = need_token()) && (group = getgrnam(tok))) {
 	if (login_info->user->pw_gid == group->gr_gid)
 	    return (1);
