@@ -39,8 +39,14 @@ int     pwok;
 	&& getsnkent(&snk, sc.serial) == 0
 	&& snk_verify(&snk, pp))
     {
+	/* cleanup memory */
+	if (snk.key != 0)
+	    memset(snk.key, 0, sizeof(snk.key));
 	return (pwd->pw_passwd);
     }
+    /* cleanup memory */
+    if (snk.key != 0)
+	memset(snk.key, 0, sizeof(snk.key));
 
     /* When SNK authentication does not work, always invoke crypt(). */
     p = crypt(pp, salt);
